@@ -66,7 +66,7 @@ func redoDirClean(root, what string) error {
 			switch what {
 			case CleanupLog:
 				if strings.HasSuffix(fi.Name(), LogSuffix) ||
-					strings.HasSuffix(fi.Name(), LogSuffix+DepSuffix) {
+					strings.HasSuffix(fi.Name(), LogRecSuffix) {
 					fmt.Println(pth)
 					if !*DryRun {
 						if err = os.Remove(pth); err != nil {
