@@ -61,12 +61,12 @@ var (
 	CReset string
 	CNone  string = "NONE"
 
-	flagNoProgress = flag.Bool("no-progress", false, fmt.Sprintf("no progress printing (%s=1), also implies -no-status", EnvNoProgress))
 	flagDebug      = flag.Bool("d", false, fmt.Sprintf("enable debug logging (%s=1)", EnvDebug))
-	flagLogWait    = flag.Bool("log-wait", false, fmt.Sprintf("enable wait messages logging (%s=1)", EnvLogWait))
-	flagLogLock    = flag.Bool("log-lock", false, fmt.Sprintf("enable lock messages logging (%s=1)", EnvLogLock))
-	flagLogPid     = flag.Bool("log-pid", false, fmt.Sprintf("append PIDs (%s=1)", EnvLogPid))
-	flagLogJS      = flag.Bool("log-js", false, fmt.Sprintf("enable jobserver messages logging (%s=1)", EnvLogJS))
+	flagNoProgress *bool
+	flagLogWait    *bool
+	flagLogLock    *bool
+	flagLogPid     *bool
+	flagLogJS      *bool
 
 	LogMutex     sync.Mutex
 	KeyEraseLine string
@@ -84,6 +84,21 @@ func init() {
 	CJS = string(t.Escape.White)
 	CReset = string(t.Escape.Reset)
 	KeyEraseLine = fmt.Sprintf("%s[K", CReset[0:1])
+
+	cmdName := CmdName()
+	if !(cmdName == CmdNameRedo || cmdName == CmdNameRedoIfchange) {
+		return
+	}
+	flagNoProgress = flag.Bool("no-progress", false,
+		fmt.Sprintf("no progress printing (%s=1), also implies -no-status", EnvNoProgress))
+	flagLogWait = flag.Bool("log-wait", false,
+		fmt.Sprintf("enable wait messages logging (%s=1)", EnvLogWait))
+	flagLogLock = flag.Bool("log-lock", false,
+		fmt.Sprintf("enable lock messages logging (%s=1)", EnvLogLock))
+	flagLogPid = flag.Bool("log-pid", false,
+		fmt.Sprintf("append PIDs (%s=1)", EnvLogPid))
+	flagLogJS = flag.Bool("log-js", false,
+		fmt.Sprintf("enable jobserver messages logging (%s=1)", EnvLogJS))
 }
 
 func erasedStatus(s, end string) string {
