@@ -587,6 +587,29 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 		}
 
 		// Was $1 touched?
+		if fd, err := os.Open(path.Join(cwdOrig, tgt)); err == nil {
+			errTouched := errors.New("$1 was explicitly touched")
+			if inodePrev == nil {
+				fd.Close()
+				runErr.Err = errTouched
+				errs <- runErr
+				return
+			} else {
+				inode, err := inodeFromFile(fd)
+				fd.Close()
+				if err != nil {
+					runErr.Err = err
+					errs <- runErr
+					return
+				}
+				if !inode.Equals(inodePrev) {
+					runErr.Err = errTouched
+					errs <- runErr
+					return
+				}
+			}
+		}
+
 		if inodePrev != nil {
 			if fd, err := os.Open(path.Join(cwdOrig, tgt)); err == nil {
 				inode, err := inodeFromFile(fd)
